@@ -15,14 +15,18 @@ struct ApiResponse {
 }
 
 fn class() -> &'static str {
-    let night: Time = Time::from_hms(19, 0, 0).unwrap();
+    let morning = Time::from_hms(0, 0, 0).unwrap();
+    let night = Time::from_hms(19, 0, 0).unwrap();
     let now = time::OffsetDateTime::now_utc()
         .to_offset(UtcOffset::from_hms(9, 0, 0).unwrap())
         .time();
-    if now > night {
-        return "HP";
+    if now < morning {
+        "MP"
+    } else if now > night {
+        "HP"
+    } else {
+        ""
     }
-    ""
 }
 
 fn main() {
@@ -35,14 +39,16 @@ fn main() {
             .send()
             .and_then(|res| res.json())
             .ok();
-        let text = match res.map(|r| r.result.len()) {
+        let int = match res.map(|r| r.result.len()) {
             Some(0) | None => {
-                println!("");
-                continue;
+                println!();
+                600
+            }
+            Some(len) => {
+                println!(r#"{{"text": "{}", "class": "{}"}}"#, len, class());
+                10
             }
-            Some(len) => len.to_string(),
         };
-        println!(r#"{{"text": "{}", "class": "{}"}}"#, text, class());
-        std::thread::sleep(Duration::from_secs(10));
+        std::thread::sleep(Duration::from_secs(int));
     }
 }
